@@ -11,7 +11,7 @@ from its submodules.  These are:
   :meth:`~base.saveall`, and :meth:`~base.setup_subplots`
 
 - To manage simulation experiments (:mod:`~modelicares.exps` module):
-  :class:`~exps.Experiment`, :mod:`~exps.doe`, :meth:`~exps.gen_experiments`,
+  :class:`~exps.Experiment`, :mod:`~modelicares.exps.doe`, :meth:`~exps.gen_experiments`,
   :class:`~exps.ParamDict`, :meth:`~exps.read_params`, :meth:`~exps.run_models`,
   :meth:`~exps.write_params`, and :meth:`~exps.write_script`
 
@@ -35,7 +35,7 @@ __author__ = "Kevin Davies"
 __email__ = "kdavies4@gmail.com"
 __copyright__ = "Copyright 2012-2013, Georgia Tech Research Corporation"
 __license__ = "BSD-compatible (see LICENSE.txt)"
-__version__ = "0.9.0"
+__version__ = "0.10.0"
 
 
 import sys
@@ -56,12 +56,11 @@ major, minor1, minor2, s, tmp = sys.version_info
 #
 # These will be available directly from modelicares; others must be loaded from
 # their submodules.
-from base import (add_arrows, add_hlines, add_vlines, animate, ArrowLine,
-                 closeall, figure, load_csv, save, saveall, setup_subplots)
-from exps import (Experiment, gen_experiments, ParamDict, read_params,
-                  run_models, write_params, write_script)
-import exps.doe as doe
-from linres import LinRes
-from multi import multiload, multiplot, multibode, multinyquist
-from simres import SimRes
-from texunit import label_number, label_quantity, unit2tex
+from modelicares.base import (add_arrows, add_hlines, add_vlines, animate, ArrowLine, 
+    closeall, figure, load_csv, save, saveall, setup_subplots)
+from modelicares.exps import (Experiment, gen_experiments, ParamDict, read_params, 
+    run_models, write_params, write_script, doe)
+from modelicares.linres import LinRes
+from modelicares.multi import multiload, multiplot, multibode, multinyquist
+from modelicares.simres import SimRes
+from modelicares.texunit import label_number, label_quantity, unit2tex
